# Na-HCO3 cotransporter, based on 6 state transporter by Crampin and Smith 2006

# Return kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

import numpy as np

def kinetic_parameters(M, include_type2_reactions, dims, V):
    # Set the kinetic rate constants

    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    fkc = 1e6
    # dissociation constants for A+B>C where Kd = k-/k+
    K_Na = 4.87e3 # [=] mM
    K_HCO3 = 8.02e-3 # [=] mM
    kp = [9.97, 8.53e-2] # [=] 1/s
    km = [5.6e1, 4.87e6] # [=] 1/s

    kf =[kp[0], fkc, fkc, kp[1], fkc*K_HCO3, fkc*K_Na]
    kr =[km[0], fkc*K_Na, fkc*K_HCO3, km[1], fkc, fkc]

    # detailed bal? They said they did it already
    # kr[5] = np.product(kf)/(np.product(kr[0:4]))

    k_kinetic = kf + kr

    # CONSTRAINTS
    N_cT = []
    K_C = []

    # volume vector
    # W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))
    W = [1] * num_cols + [V['V_myo'], V['V_o']]*2 + [V['V_myo']]*len(kf)

    return (k_kinetic, N_cT, K_C, W)













